@@ -11,12 +11,10 @@ c   This is the interface to draw new volumes.
       record /epPos/ p(*)  ! output.   position given in local coord.
 
 c      
-      if(comp.struc(1:8) .eq. 'cap') then
-         call epDraw_cap(comp, p, n)
-      elseif(comp.struc(1:8) .eq. 'ellips') then
-         call epDraw_ellips(comp, p, n)
-      elseif(comp.struc(1:8) .eq. 'angle') then
-         call epDraw_angle(comp, p, n)
+      if(comp.struc(1:8) .eq. 'sqpipe') then
+         call epDraw_sqpipe(comp, p, n)
+      elseif(comp.struc(1:8) .eq. 'ciecone') then
+         call epDraw_ciecone(comp, p, n)
 c---  elseif(comp.struc(1:8) .eq. '%2') then
 c---     call epDraw_%2(comp, p, n)
       else
