@@ -1,5 +1,6 @@
 #include "ZepMaxdef.h"
        integer Nevrun   ! event counter generated in this run
+       logical DoUpdateNo ! if t, update Nevrun in epe1ev
        integer iowk     ! logical  device number used for input disk file
        integer IoTrace  ! logical device number of trace info. 
                         ! If >0, only charged ptcl tracks are recorded
@@ -22,6 +23,6 @@
        integer epHooki(EPMAX_UHOOKI)
        real*8 epHookr(EPMAX_UHOOKR)
        common /epManag/ epHookr, epHooki, epHooks,
-     *  Nevrun, MsgLevel, IoTrace
+     *  Nevrun, MsgLevel, IoTrace, DoUpdateNo
 
        common /epManagC/ MediaDir, TraceDir, epHookc
