@@ -70,4 +70,8 @@
 #define EPMAX_UHOOKR 10
       !     number of user definable character, integer, real*8
       !     variables in sepicsfile
+#define MAXERGNODE_MUPAIR 10
+      !  max # of energy nodes at which exact cross-sections 
+      !  are given for pair creation by muon at low eneries
+      !  (3 GeV to 1500 GeV)
 #endif
