@@ -11,7 +11,8 @@ c        this is used for a table with LPM
       if(Eg .lt. media.cnst.PrEg1H) then
          write(0,*) ' Eg=',Eg,'<media.cnst.PrEg1H=',media.cnst.PrEg1H
          call cerrorMsg('Eg is too low for epPrHSamp',1)
-         call epfordebug('in epPrHSamp')
+c           next call results in undef for uiaev  etc.
+c         call epfordebug('in epPrHSamp') 
          stop 1111
 
       elseif(Eg .lt. media.cnst.PrEg2H) then
