@@ -22,6 +22,9 @@ c
       character*120 msg
       real*8  tmpel, el2, el
       integer i, cnxx, j, cnx, jcon
+      record /epPos/postemp
+      record /epDirec/ dirtemp
+
 
 c          present comp, boundary
       call epbndry2(Cn, el, jcon)
@@ -81,6 +84,11 @@ c         issue messages.
          endif
          if(Cn .ne. cnxx) then
             cTrack.cn = cnxx
+            call epl2w(Cn, cTrack.pos, postemp)
+            call epw2l(cnxx, postemp,  cTrack.pos)
+
+            call epl2wd(Cn, cTrack.w,  dirtemp)
+            call epw2ldm(cnxx, dirtemp, cTrack.w, cTrack.p)
             pos = cTrack.pos
             call epnewComp(cTrack)
          else
