@@ -99,8 +99,10 @@ c              component # is undefined yet
       call epempty
 c      Stack_pos = 0
 c      StackDisk = 0
-      Nevrun=0
+      Nevrun=1   !  >= 9.06 (<=9.05; Nevrun=0)
+      DoUpdateNo =.true.  ! >=9.06
 c                read basic parameter
+
       call epprmr(dsn1)
 c                compute something using basic parameters
       call epcmp1
@@ -172,7 +174,7 @@ c             init for 1 event
        FirstInt.x = -100000.d0
        FirstInt.y = -100000.d0
        FirstInt.z = -100000.d0
-       Nevrun = Nevrun + 1
+c       Nevrun = Nevrun + 1     ! <= 9.05
        pathInB=0.
        SumDe = 0.
        Move.Abort = 0     !  if this become non zero for an event, 
@@ -229,6 +231,11 @@ c<<<<<<<<<<<<<<<<<<<
 c               user dependent end process
 
        if(Move.Abort .le. 1) call ue1ev
+       if( DoUpdateNo ) then 
+          Nevrun = Nevrun +1
+       else
+          DoUpdateNo = .true.
+       endif
        if(Trace) then
           close(abs(IoTrace))
        endif
@@ -271,6 +278,14 @@ c            inquire  current event number created in this run
        integer nev
        nev = Nevrun
        end
+c      ***********************
+      subroutine epSkipUpdateNo
+      implicit none
+#include  "ZepManager.h"
+c            disable the update of Nevrun
+      DoUpdateNo = .false.
+
+      end
 
        subroutine epfl1
        implicit none
@@ -311,7 +326,6 @@ c          add  time
 c          energy check
           call epchckE(Move.Track, icon)
 
-
           if(icon .eq. 0 ) then
 c           adjust momentum; because of  energy change
              if(cTrack.p.charge .ne. 0) then
@@ -588,6 +602,7 @@ c                    exiting from Cn to cnx
                Move.Abort = 0   ! but continue simulation
             else
                call  epempty    ! empty the sack. discard ev.
+               call  epSkipUpdateNo
             endif
          endif
       endif
@@ -626,6 +641,7 @@ c             count entering ptcls;  from info to Move.Track.cn (=Cn)
                   Move.Abort = 0 ! but continue simulation
                else
                   call  epempty ! empty the sack. discard ev.
+                  call  epSkipUpdateNo
                endif
             endif
          endif
@@ -861,10 +877,11 @@ c          this will not happen if muon specific loss exists.
             Move.dEeff = Move.dE*cf
             Move.dEioni = Move.dE
          endif
-
          Move.Track.p.fm.p(4) = Move.Track.p.mass
-         Move.dl = dx * Media(MediaNo).gtocm /
-     *     Media(MediaNo).rhoc
+         Move.dl =min( dx * Media(MediaNo).gtocm /
+     *     Media(MediaNo).rhoc, Move.dl)
+         Move.dx = dx
+
          Move.Track.pos.x = cTrack.pos.x + Move.dl* cTrack.w.x 
          Move.Track.pos.y = cTrack.pos.y + Move.dl* cTrack.w.y
          Move.Track.pos.z = cTrack.pos.z + Move.dl* cTrack.w.z
@@ -1454,6 +1471,7 @@ c                endif                               <<<<<<<<<<<<
        endif
        if(Move.Abort .ne. 0) then
           call epempty          ! empty the stack
+          call epSkipUpdateNo
           icon = 1
        endif
        end
@@ -1522,8 +1540,9 @@ c      ************************
       character*100 msg
       integer k,  ia, iz
       real*8 xs
-
+      integer inela
       record /epPos/temppos
+
 c
 c/////////////
 c      logical show
@@ -1643,10 +1662,23 @@ c                 can be called by all muons.
             FirstC=.false.
          elseif(Move.proc .eq. 'coll' .or.
      *           Move.proc .eq. 'decay') then
-            FirstInt = cTrack.pos
-            Proc1 = Move.proc
-            call epsaveFirstCol
-            FirstC=.false.
+            if(Move.proc == 'coll') then
+               if(ActiveMdl == 'jam') then
+c                            if hadron proj, inela could be 0 or 1
+                  call cjamElaInfo(1, inela)
+               else
+                  inela = 1
+               endif
+            else
+               inela = 1
+            endif
+            if(inela == 1 ) then
+c                   ielastic/decay so  regard as 1st interaction   
+               FirstInt = cTrack.pos
+               Proc1 = Move.proc
+               call epsaveFirstCol
+               FirstC=.false.
+            endif
          elseif(cTrack.p.code .eq. kmuon .and.
      *         (  Move.proc .eq. 'pair' .or.
      *           Move.proc .eq. 'brem' .or.
