@@ -65,6 +65,9 @@ c
       if(media.sumns /= smallxs .and. media.sumns /= largexs) then
 c           prop to rhoc so next two are indep. of rhoc
          xs = media.sumns/media.nd ! mb/cm3 /(1/cm3)
+c/////////////
+c         write(*,*) ' xs=',xs, ' mb'
+c////////////
          mfp = 10.*media.rho/(media.sumns*mbTocm2)   ! in kg/m2. Not in g/cm2
                                           ! to be consistent with other  part.
       elseif( media.sumns == smallxs ) then
@@ -92,11 +95,11 @@ c  #include "ZepTrackp.h"
       sumns=0. 
       do i =1, media.noOfElem
          if(pj.code >= kpion .and. pj.code <= knuc ) then
-            if( (pj.fm.p(4)-pj.mass)  < 10.d0 )  then ! include elastic
+c            if( (pj.fm.p(4)-pj.mass)  < 10.d0 )  then ! include elastic
                call ctotx(pj, media.elem(i).A,  xs)
-            else
-               call cinelx(pj, media.elem(i).A,  xs)
-            endif
+c            else
+c               call cinelx(pj, media.elem(i).A,  xs)
+c            endif
          else
             call cinelx(pj, media.elem(i).A,  xs)
          endif
